@@ -2,6 +2,6 @@ from pyhelpers import dir, geom, ops, settings, sql, store, text
 
 __package_name__ = 'pyhelpers'
 __author__ = 'Qian Fu'
-__version__ = '1.2.1'
+__version__ = '1.2.2'
 __email__ = 'qian.fu@outlook.com'
-__description__ = 'A toolkit for facilitating data manipulation using Python.'
+__description__ = 'A toolkit for facilitating data manipulation in Python.'
